# frozen_string_literal: true

require 'apiphobic/middleware/configurable'

module  Apiphobic
module  Matchers
class   Version
  include Middleware::Configurable

  attr_accessor :accept_header,
                :application_name,
                :default_version,
                :request,
                :version_constraint

  def initialize(version_constraint:,
                 application_name: configuration.application_name,
                 default_version:  configuration.default_api_version)

    self.application_name   = application_name
    self.default_version    = default_version
    self.version_constraint = version_constraint
  end

  def matches?(raw_request)
    self.request       = ::Apiphobic::Requests::AcceptHeader.resolve(raw_request)
    self.accept_header = ::Apiphobic::AcceptHeader.new(request.accept_header,
                                                       application_name: application_name)

    requested_version == version_constraint
  end

  private

  def requested_version
    accept_header.version || default_version
  end
end
end
end
