# frozen_string_literal: true

require 'singleton'

module  Apiphobic
module  Middleware
  class Configuration
    include Singleton

    attr_accessor :application_name
    attr_writer   :allowed_api_subdomains,
                  :allowed_method_overrides,
                  :allowed_subdomains,
                  :default_api_version

    def to_h
      {
        allowed_api_subdomains:   allowed_api_subdomains,
        allowed_method_overrides: allowed_method_overrides,
        allowed_subdomains:       allowed_subdomains,
        application_name:         application_name,
        default_api_version:      default_api_version,
      }
    end

    def allowed_subdomains
      @allowed_subdomains || ['api']
    end

    def allowed_method_overrides
      @allowed_method_overrides || {}
    end

    def allowed_api_subdomains
      @allowed_api_subdomains || ['api']
    end

    def default_api_version
      @default_api_version || '1'
    end
  end

  def self.configure
    yield configuration
  end

  def self.configuration
    @configuration ||= Configuration.instance
  end
end
end
