# frozen_string_literal: true

require 'apiphobic/accept_header'

module  Apiphobic
module  Requests
class   AcceptHeader
  ACCEPT_PARAM_PATTERN = /(?:\A|&)\_accept=(.+?)(?=\z|&)/

  attr_accessor :request

  def initialize(request)
    self.request = request
  end

  def self.resolve(request)
    return request if request.class == self

    new(request)
  end

  def accept_header
    if accept_header_from_header.valid? || accept_header_from_params.invalid?
      raw_accept_header_from_header
    else
      raw_accept_header_from_params
    end
  end

  private

  def accept_header_from_header
    @accept_header_from_header ||= \
      ::Apiphobic::AcceptHeader.new(raw_accept_header_from_header,
                                    application_name: /.*?/)
  end

  def accept_header_from_params
    @accept_header_from_params ||= \
      ::Apiphobic::AcceptHeader.new(raw_accept_header_from_params,
                                    application_name: /.*?/)
  end

  def raw_accept_header_from_header
    if request.respond_to?(:headers)
      request.headers['Accept']
    else
      request['HTTP_ACCEPT']
    end
  end

  def raw_accept_header_from_params
    if request.respond_to?(:params)
      request.params['_accept']
    else
      URI.unescape(request['QUERY_STRING'][ACCEPT_PARAM_PATTERN, 1] || '') # rubocop:disable Lint/UriEscapeUnescape
    end
  end
end
end
end
